==> haskell-pager-0.1.1.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-KRcmqe9jHStAZYCxkWlzsc
key:                  pager-0.1.1.0-KRcmqe9jHStAZYCxkWlzsc
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  423241d80d77b08150e51806b75fe467
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-KRcmqe9jHStAZYCxkWlzsc
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-92zzct0epxXEfUwXKZuiQR
    conduit-extra-1.3.6-4W9taQ73CBv99u6T6hlbxs directory-1.3.6.2
    process-1.6.16.0 resourcet-1.2.6-CWtJGH6acq3JRI3WPjesPj
    safe-0.3.21-DycKuNeB2NrH0Uhgd9RWtv terminfo-0.4.1.5 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-O4hPUhW6gvIjFg2qaDJB6
key:                  pager-0.1.1.0-O4hPUhW6gvIjFg2qaDJB6
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  0e49e91f415e0c100a5be28d6722d0de
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-O4hPUhW6gvIjFg2qaDJB6
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-4nxUBFRe7qx8JsNUl8azVI
    conduit-extra-1.3.6-H2ARZzMf44UD4DNef0Nprn directory-1.3.6.2
    process-1.6.16.0 resourcet-1.2.6-CWtJGH6acq3JRI3WPjesPj
    safe-0.3.21-DycKuNeB2NrH0Uhgd9RWtv terminfo-0.4.1.5 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
